import * as storage from '@root/utils/storage';
import getData from '@root/utils/request';
import Taro from '@tarojs/taro';
import { isReqSuccess } from '@root/utils/tool';
import { firstCharToLowerCase } from '../utils/tool';

async function saveSafeArea(dispatch) {
  const res = await Taro.getSystemInfo();
  console.log('system info:', res);
  if (res) {
    const isAndroid =  res.platform === 'android';
    storage.set('isAndroid', isAndroid, true);
    dispatch({
      type: 'app/update',
      payload: {
        statusBarHeight: res.statusBarHeight,
        safeArea: res.safeArea || {},
        isAndroid,
      }
    })
  }
}

export function logout() {
  return async (dispatch) => {
    storage.clear();
    Taro.reLaunch({ url: '/pages/login/index' });
    dispatch({
      type: 'app/logout',
    });
  }
}

export function initApp() {
  return async (dispatch, getState ) => {
    saveSafeArea(dispatch);
  }
}


export function login({ username, password }) {
  return async (dispatch, getState) => {
    const res = await getData('authentication/login', { UserName: username, Password: password }, true);
    if (!isReqSuccess(res)) {
      // dispatch(logout());
      return res;
    }
    const userData = firstCharToLowerCase(res.data);
    
    const isSuperAdmin = userData.backgroundPermission === 3;
    if(isSuperAdmin) {
      return {
        code: 'err',
        msg: '该账号没有访问权限',
      }
    }

    const companyInfoRes = await getData('company/queryFrontDeskCompanyById', { id: userData.companyId });
    if (!isReqSuccess(companyInfoRes)) {
      return companyInfoRes;
    }


    const { data: { company: { SoftwareVersion } = {} } = {} } = companyInfoRes;

    // 角色判断
    // const { app: appStore } = getState();
    // if (appStore.appType && userData.userType !== appStore.appType) { // 登录角色权限不符合，退出登录
    //   hint('账号权限不足');
    //   dispatch(logout());
    //   return false;
    // }
    const payload = {
      accountId: userData.id,
      accountName: userData.cnName,
      customerId: userData.companyId,
      avatorUrl: userData.headImgUrl,
      isMini: SoftwareVersion === 'Mini',
    };
    storage.set('accountId', payload.accountId);
    storage.set('isMini', payload.isMini)
    dispatch({
      type: 'app/login',
      payload,
    });

    return res;
  }
};
