import { Text, View } from '@tarojs/components';
import Taro from '@tarojs/taro';
import React, { useCallback, useEffect, useState } from 'react';
import { AtButton } from 'taro-ui';
import YInput from '@root/components/YInput';
import styles from './index.module.scss';
import { login } from '@root/actions/app';
import { useDispatch } from 'react-redux';
import { isReqSuccess } from '@root/utils/tool';
import Page from '@root/components/Page';

const inputField = setter => ({ detail: { value } }) => setter(value);

export default function Login() {
  const [errText, setErrText] = useState('');
  const [account, setAccount] = useState('');
  const [password, setPassword] = useState('');
  const dispatch = useDispatch();

  const onLogin = useCallback(async () => {
    if(!account) { hint('账号/手机号不能为空'); return;}
    if (!password) { hint('密码不能为空'); return; }
    Taro.showLoading({ title: '', mask: true });
    const res = await dispatch(login({
      username: account,
      password: password,
    }));
    Taro.hideLoading();
    if(!isReqSuccess(res)) {
      setErrText(res.msg);
      return;
    }
    // Taro.switchTab({ url: '/pages/project/index' });
    Taro.navigateTo({ url: '/pages/project/index' });
  }, [account, password, dispatch]);

  useEffect(() => {
    setErrText('');
  }, [account, password])

  return (
    <Page className={styles.main} wrapperClassName={styles.page}>
      <Text className={styles.logo}>LOCKING</Text>
      <YInput wrapperClassName={styles.inpWrapper} placeholder="请输入手机号或账号"
        value={account}
        onInput={inputField(setAccount)}
      />
      <YInput wrapperClassName={styles.inpWrapper} placeholder="请输入密码" type="password"
        value={password}
        onInput={inputField(setPassword)}
      >
        {/* <Text>忘记密码</Text> */}
      </YInput>
      <View className={styles.err}>
        {errText ? <Text>{errText}</Text>: null }
      </View>
      <AtButton className={styles.button} type="primary" onClick={onLogin}>登入</AtButton>
    </Page>
  )
}
