import { Image, Text, View, ScrollView } from '@tarojs/components';
import React, { useCallback, useEffect, useLayoutEffect, useState } from 'react';
import Taro from '@tarojs/taro';
import styles from './index.module.scss';
import Avator from '@root/components/Avator';
import Welcome from './components/welcome';
import { fetchProjectList } from './service';
import Page from '@root/components/Page';
import { getFileUrl } from '@root/service/oss';
import { AtIcon, AtSearchBar } from 'taro-ui';

export default function ProjectListView() {
  const [projectList, setProjectList] = useState([]);
  const [searchFlag, setSearchFlag] = useState(false);
  const [effectKeywords, setEffectKeywords] = useState('');

  const fetchList = useCallback(async () => {
    const dataList = await fetchProjectList();
    setProjectList(dataList);
  }, []);

  useEffect(() => {
    fetchList();
  }, [fetchList])

  useEffect(() => {
    if (!searchFlag) {
      setEffectKeywords('');
    }
  }, [searchFlag])

  return (
    <Page wrapperClassName={styles.page} headerColor={searchFlag ? '#ebebeb' : undefined}>
      <ScrollView className={styles.project} scrollY>
        {
          !searchFlag
            ? (
              <>
                <View className={[styles.wrapPadding, styles.header]}>
                  <Avator className={styles.avator} onClick={() => Taro.navigateTo({ url: '/pages/usercenter/index' })} />
                  <AtIcon value="search" color="#999" onClick={() => setSearchFlag(true)} />
                </View>
                <Welcome className={[styles.wrapPadding, styles.mt10]} />
              </>
            )
            : (
              <AtSearchBar
                className={styles.search}
                value={effectKeywords}
                onChange={setEffectKeywords}
                showActionButton
                focus
                actionName="取消"
                // onBlur={() => {
                //   if(!effectKeywords) {
                //     setSearchFlag(false);
                //   }
                // }}
                onActionClick={() => setSearchFlag(false)}
                onClear={() => { setEffectKeywords(''); }}
              />
            )
        }
        {
          projectList.length && !searchFlag
            ? (
              <View className={[styles.listTitle, styles.wrapPadding]}>
                <Text>我的项目</Text>
              </View>
            )
            : null
        }
        {
          projectList.map(project => {
            if(effectKeywords && project.projName.indexOf(effectKeywords) === -1) {
              return null;
            }
            return (
              <View
                className={styles.projectItem}
                key={project.id}
                onClick={() => Taro.navigateTo({
                  url: `/pages/workspace/workspace?projectId=${project.id}&&projectName=${project.projName}`,
                })}
              >
                <Image className={styles.img} src={project.showImgUrl} />
                <View className={styles.label}>
                  <Text>{project.projName}</Text>
                </View>
              </View>
            )
          })
        }
        {
          !projectList.length
            ? (
              <View className={styles.empty}>
                <Image className={styles.empty_img} src={getFileUrl('oss://assets/empty.png')} />
                <Text className={styles.text}>暂无项目</Text>
              </View>
            )
            : null
        }
      </ScrollView>
    </Page>
  )
}



