import React, { useCallback, useEffect, useLayoutEffect, useState } from 'react';
import Page from '@root/components/Page';
import { AtSearchBar } from 'taro-ui';
import styles from './index.module.scss';
import FileExplorer from '@root/components/FileExplorer';
import { fetchProjectList, fetchProjectRemovedFiles } from './service';

export default function RecycleView() {
  const [tempKeywords, setTempKeywords] = useState('');
  const [effectKeywords, setEffectKeywords] = useState('');
  const [currentNode, setCurrentNode] = useState(null);
  const [nodeHash, setNodeHash] = useState({});

  useLayoutEffect(() => {
    fetchProjectList()
        .then(([rootNode, nextNodeHash]) => {
          setCurrentNode(rootNode);
          setNodeHash(nextNodeHash);
        })
  }, []);

  const gotoNode = useCallback((nextFileNode) => {
    if(nextFileNode.isRoot) {
      fetchProjectList()
        .then(([rootNode, nextNodeHash]) => { setCurrentNode(rootNode); setNodeHash(nextNodeHash); })
    } else if(nextFileNode.isProject) {
      fetchProjectRemovedFiles(nextFileNode)
        .then(([nextNodeHash]) => {
          setCurrentNode(nextFileNode);
          setNodeHash(prevHash => ({ ...prevHash, ...nextNodeHash }));
        })
    } else {
      setCurrentNode(nextFileNode);
    }
  }, [])

  return (
    <Page
      className={styles.page}
      title={
        currentNode && currentNode.id !== 'root'
          ? currentNode.label
          : '回收站'
      }
      headerColor="#EBEBEB"
      leftText={
        currentNode && currentNode.id !== 'root'
          ? '返回'// nodeHash[currentNode.parentId].label || '项目列表'
          : undefined
      }
      onClickLeftIcon={() => {
        setCurrentNode(prevNode => nodeHash[prevNode.parentId])
      }}
    >
      <AtSearchBar
        className={styles.search}
        value={tempKeywords}
        onChange={setTempKeywords}
        onActionClick={() => setEffectKeywords(tempKeywords)}
        onClear={() => {setEffectKeywords(''); setTempKeywords('');}}
      />
      {
        currentNode 
         ? (
          <FileExplorer
            className={styles.list}
            node={currentNode}
            gotoNode={gotoNode}
            nodeHash={nodeHash}
          />
         )
         : null
      }
      
    </Page>
  )
}
