import getData from '@root/utils/request';
import * as storage from '@root/utils/storage';
import { FileNode, firstCharToLowerCase } from '@root/utils/tool';
import { hideLoading, showLoading } from '@tarojs/taro';

export async function fetchProjectList() {
  const accountId = storage.get('accountId');
  showLoading();
  const res = await getData('project/queryAllProjectListByUserId', { userId: accountId });
  hideLoading();
  const nodeHash = {};
  const rootNode = new FileNode('root', '', null, 'folder');
  rootNode.isRoot = true;
  nodeHash[rootNode.id] = rootNode;
  (res.data || []).forEach((upperProject) => {
    if (!upperProject.HasFile) { return; }
    // const project = firstCharToLowerCase(upperProject);
    const projectFolder = new FileNode(upperProject.Id, upperProject.ProjName, rootNode.id, 'folder');
    projectFolder.isProject = true;
    nodeHash[projectFolder.id] = projectFolder;
    // if (upperProject.NodeFolder) {
    //   upperProject.NodeFolder
    //     .forEach((upperNodeFolder) => {
    //       if(upperNodeFolder.FirstFolderId === upperNodeFolder.Id ||
    //         upperNodeFolder.NodeId === '0') { return; }
    //       const folderNode = new FileNode(upperNodeFolder.Id, upperNodeFolder.FolderName, projectFolder.id, 'folder');
    //       nodeHash[folderNode.id] = folderNode;
    //       projectFolder.append(folderNode.id);
    //     });
    //   ;
    // }
    rootNode.append(projectFolder.id)
  }, []);
  return [rootNode, nodeHash];
}

export async function fetchProjectRemovedFiles(projectNode) {
  showLoading();
  const hash = {};
  const isMini = storage.get('isMini');
  const res = await getData('file/queryFilesFromRecycleBinByProjectId', { projectId: projectNode.id });
  hideLoading();
  projectNode.removeAllChildrenIds();
  (res.data || []).forEach((topNode) => {
    if (!topNode.ProjArchives) { return; }
    let parentNode = projectNode;
    if (!isMini) {
      const node = new FileNode(topNode.Id, topNode.FolderName, projectNode.id, 'folder');
      hash[node.id] = node;
      projectNode.append(node.id);
      parentNode = node;
    }
    topNode.ProjArchives.forEach((upperFileItem) => {
      const fileItem = firstCharToLowerCase(upperFileItem);
      const lastFolder = generateFolder(hash, `${topNode.FolderName}${fileItem.relativePath ? `/${fileItem.relativePath}` : ''}`, parentNode);
      const file = new FileNode(fileItem.id, fileItem.archName, parentNode.id, 'file', fileItem);
      lastFolder.append(file.id);
      // parentNode.append(file);
      hash[file.id] = file;
    });
  });
  console.log('fetchProjectRemovedFiles:', res);
  return [hash];
}


function generateFolder(folderMap, filePath, topNode) {
  const paths = filePath.split("/");
  let lastFolder = topNode;
  paths.forEach((_, idx) => {
    if (idx === 0) { // 第一位为节点文件夹的名称，已在前文创建，不在重复
      return;
    }
    const fullRelativePath = `${paths.slice(0, idx + 1).join("/")}`;
    let folder;
    if (folderMap[fullRelativePath]) {
      folder = folderMap[fullRelativePath];
    } else {
      const folderName = paths[idx];
      const parentNodeId = idx === 1 ? topNode.id : paths.slice(0, idx).join('/');
      folder = new FileNode(fullRelativePath, folderName, parentNodeId, 'folder');
      folderMap[fullRelativePath] = folder;
      (folderMap[folder.parentId] || topNode)
        .append(folder.id);
    }
    lastFolder = folder;
  });
  return lastFolder;
}