import Page from '@root/components/Page';
import { useRequest } from '@root/utils/hooks';
import getData from '@root/utils/request';
import { get } from '@root/utils/storage';
import Taro from '@tarojs/taro';
import { firstCharToLowerCase } from '@root/utils/tool';
import React, { useCallback, useState } from 'react';
import styles from './usercenter.module.scss';
import { AtList, AtListItem, AtModal } from 'taro-ui';
import { ScrollView, View } from '@tarojs/components';
import Avator from '@root/components/Avator';
import { useDispatch } from 'react-redux';
import { logout } from '@root/actions/app';

export default function UserCenter() {
  const dispatch = useDispatch();
  const [modalVisible, setModalVisible] = useState(false);
  const { data } = useRequest(async () => {
    const accountId = get('accountId');
    const res = await getData('user/queryUserByUserId', { id: accountId });
    return firstCharToLowerCase(res.data);
  });

  return (
    <Page
      leftText="我的项目"
      wrapperClassName={styles.page}
      onClickLeftIcon={() => Taro.navigateBack()}
      headerColor="#f0f0f0"
    >
      <View className={styles.banner}>
        <View className={styles.name}>{data?.cnName}</View>
        <Avator className={styles.avator} />
        <View className={styles.gradient} />
      </View>
      <ScrollView className={styles.scroll} scrollY>
        <AtList className={styles.itemList}>
          <AtListItem
            title="账号信息"
            className={styles.subtitle}
          />
          <AtListItem
            className={styles.item}
            title="姓名"
            extraText={data?.cnName}
          />
          <AtListItem
            className={styles.item}
            title="手机号"
            extraText={data?.phone}
          />
          <AtListItem
            className={styles.item}
            title="邮箱"
            extraText={data?.email}
          // arrow="right"
          />
          <AtListItem
            title="职务信息"
            className={styles.subtitle}
          />
          <AtListItem
            className={styles.item}
            title="所在部门"
            extraText={data?.deptName}
          />
          <AtListItem
            className={styles.item}
            title="职位"
            extraText={data?.position}
          />
        </AtList>
      </ScrollView>
      <View className={styles.foot}>
        <View className={styles.logout} onClick={() => setModalVisible(true)}>
          退出账户
        </View>
      </View>
      <AtModal
        className={styles.modal}
        isOpened={modalVisible}
        title="确定退出账户？"
        cancelText='取消'
        confirmText='确认'
        onCancel={() => setModalVisible(false)}
        onConfirm={() => dispatch(logout())}
      />
    </Page>
  )
}