import React, { useCallback, useEffect, useLayoutEffect, useState } from 'react';
import Page from '@root/components/Page';
import { AtSearchBar } from 'taro-ui';
import styles from './workspace.module.scss';
import FileExplorer from '@root/components/FileExplorer';
import { fetchProjectFiles, fetchNodeFiles } from './workspace.service';
import { useRouter } from '@tarojs/taro';
import Taro from '@tarojs/taro';

export default function Workspace() {
  const { params: { projectId, projectName } } = useRouter();
  const [tempKeywords, setTempKeywords] = useState('');
  const [effectKeywords, setEffectKeywords] = useState('');
  const [currentNode, setCurrentNode] = useState(null);
  const [nodeHash, setNodeHash] = useState({});

  useLayoutEffect(() => {
    fetchProjectFiles(projectId, projectName)
      .then(([rootNode, nextNodeHash]) => {
        setCurrentNode(rootNode);
        setNodeHash(nextNodeHash);
      })
  }, [projectId, projectName]);


  useEffect(() => {
    setTempKeywords('');
    setEffectKeywords('');
  }, [currentNode])

  const gotoNode = useCallback((nextFileNode) => {
    if (nextFileNode.isProject) {
      fetchProjectFiles(projectId, projectName)
        .then(([rootNode, nextNodeHash]) => { setCurrentNode(rootNode); setNodeHash(nextNodeHash); })
    } else if (nextFileNode.isNode) {
      fetchNodeFiles(nextFileNode)
        .then(([nextNodeHash]) => {
          setCurrentNode(nextFileNode);
          setNodeHash(prevHash => ({ ...prevHash, ...nextNodeHash }));
        })
    } else {
      setCurrentNode(nextFileNode);
    }
  }, [projectId, projectName])

  return (
    <Page
      className={styles.page}
      title={
        currentNode
          ? currentNode.label
          : projectName
      }
      headerColor="#EBEBEB"
      leftText= "返回"
      onClickLeftIcon={() => {
        if(currentNode.isProject) {
          Taro.navigateBack();
        } else {
          setCurrentNode(prevNode => nodeHash[prevNode.parentId])
        }
      }}
    >
      <AtSearchBar
        className={styles.search}
        value={tempKeywords}
        onChange={setTempKeywords}
        onActionClick={() => setEffectKeywords(tempKeywords)}
        onClear={() => { setEffectKeywords(''); setTempKeywords(''); }}
      />
      {
        currentNode
          ? (
            <FileExplorer
              className={styles.list}
              node={currentNode}
              gotoNode={gotoNode}
              nodeHash={nodeHash}
              keywords={effectKeywords}
            />
          )
          : null
      }

    </Page>
  )
}