import getData from '@root/utils/request';
import * as storage from '@root/utils/storage';
import { FileNode, firstCharToLowerCase, isReqSuccess } from '@root/utils/tool';
import { hideLoading, showLoading } from '@tarojs/taro';



function generateFolder(folderMap, filePath, topNode) {
  const paths = filePath.split("/");
  let lastFolder = topNode;
  paths.forEach((_, idx) => {
    if (idx === 0) { // 第一位为节点文件夹的名称，已在前文创建，不在重复
      return;
    }
    const fullRelativePath = `${paths.slice(0, idx + 1).join("/")}`;
    let folder;
    if (folderMap[fullRelativePath]) {
      folder = folderMap[fullRelativePath];
    } else {
      const folderName = paths[idx];
      const parentNodeId = idx === 1 ? topNode.id : paths.slice(0, idx).join('/');
      folder = new FileNode(fullRelativePath, folderName, parentNodeId, 'folder');
      folderMap[fullRelativePath] = folder;

      (folderMap[folder.parentId] || topNode)
        .append(folder.id);
    }

    // const parentRelativePath = folder.parentFolderPath;


    lastFolder = folder;
  });
  return lastFolder;
}


async function fetchNodeFolders(projectNode, hash) {
  const isMini = storage.get('isMini');
  const res = await getData('folder/queryAllNodeFolderListByProjectId', { projectId: projectNode.id });
  if (!isReqSuccess(res)) { return []; }

  const { folder } = res.data;
  return folder.reduce((iList, upperFolder) => {
    if (upperFolder.FolderName === "公共文件夹") {
      return iList;
    }
    if (upperFolder.NodeId === upperFolder.TemplateId) {
      return iList;
    }
    // const folder = firstCharToLowerCase(upperFolder);
    const folder = new FileNode(upperFolder.Id, upperFolder.FolderName, projectNode.id, 'folder');
    folder.isNode = true;
    hash[folder.id] = folder;
    if (!isMini) {
      projectNode.append(folder.id);
    }

    iList.push(folder);
    return iList;
  }, []);
}

export async function fetchNodeFiles(parentNode, hash = {}, nodeFolderId = parentNode.id) {
  const accountId = storage.get('accountId');
  showLoading();
  const res = await getData('folder/queryFileListByFolderIdAndUserId', { folderId: nodeFolderId, userId: accountId });
  hideLoading();
  if (!isReqSuccess(res)) { return []; }
  const { myFile, workFile } = res.data;
  parentNode.removeAllChildrenIds();
  (myFile || []).concat(workFile || []).forEach((upperFileItem) => {
    const fileItem = firstCharToLowerCase(upperFileItem);
    const lastFolder = generateFolder(hash, `${parentNode.label}${fileItem.relativePath ? `/${fileItem.relativePath}` : ''}`, parentNode);
    const file = new FileNode(fileItem.id, fileItem.archName, parentNode.id, 'file', fileItem);
    lastFolder.append(file.id);
    // parentNode.append(file);
    hash[file.id] = file;
  });
  return [hash];
}


export async function fetchProjectFiles(projectId, projectName) {
  showLoading();
  const hash = {};
  const projectNode = new FileNode(projectId, projectName, null, 'folder');
  projectNode.isProject = true;
  hash[projectNode.id] = projectNode;
  const isMini = storage.get('isMini');
  // project -> nodeFolders
  const nodeList = await fetchNodeFolders(projectNode, hash);
  hideLoading();

  // 如果是mini版本，则直接拉去第一个文件夹的内容挂在到projectNode上
  if (isMini && nodeList.length) {
    const node = nodeList[0];
    await fetchNodeFiles(projectNode, hash, node.id);
  }
  return [projectNode, hash];
}