import { useCallback, useEffect, useLayoutEffect, useRef, useState } from 'react';

export function useInterval(fn, delay, options) {
  const immediate = options?.immediate;

  const fnRef = useRef();
  fnRef.current = fn;

  useEffect(() => {
    if (delay === undefined || delay === null) return;
    if (immediate) {
      fnRef.current?.();
    }
    const timer = setInterval(() => {
      fnRef.current?.();
    }, delay);
    return () => {
      clearInterval(timer);
    };
  }, [delay]);
}

export function useRequest(service) {
  const [loading, setLoading] = useState(false);
  const [data, setData] = useState(null);
  const ref = useRef();
  ref.current = service;

  const wrapperFn = useCallback(async () => {
    setLoading(true);
    const res = await ref.current();
    setLoading(false);
    setData(res);
  }, [ref])

  useLayoutEffect(() => {
    wrapperFn();
  }, [wrapperFn])


  return {
    loading,
    data,
    trigger: wrapperFn
  }
}