import Taro from '@tarojs/taro';
import { parseRequest } from './request.config';
import { firstCharToLowerCase, handleRequest, hint } from './tool';
import * as storage from './storage';

const ip = 'https://pro.locking.cn:9443';
const downloadUrl = 'https://pro.locking.cn:9443/ipfs';

const header = { 'Content-Type': 'application/json' };

let gsessionId = storage.get('gssesionid');

const getData = async (path, params = {}, silent = false) => {
  // const datas = JSON.stringify({ ...params });
  if(gsessionId) {
    header['Cookie'] = gsessionId;
  }
  const [method, fullpath] = parseRequest(path);
  const httpResponse = await Taro.request({
    url: `${ip}/${fullpath}`,
    data: params,
    header,
    method,
  });
  const ifhaveCookie = httpResponse.cookies[0] && httpResponse.cookies[0].match(/gsessionid\=([\d\w]*)/);
  if(ifhaveCookie) {
    gsessionId = ifhaveCookie[0];
  }
  if (httpResponse.statusCode !== 200) {
    debugger;
  }
  const outputData = firstCharToLowerCase(httpResponse.data);
  outputData.httpCode = httpResponse.statusCode;
  handleRequest(outputData)
    .httpError(() => {
      if(!silent) {
        hint('网络错误，请稍微再试');
      }
    })
    .error(() => {
      if(!silent) {
        hint(outputData.msg);
      }
    });
  return outputData;
}

export const downloadFile = (ipfsCid, options) => Taro.downloadFile({
  url: `${downloadUrl}/${ipfsCid}`,
  ...options,
})

export default getData;